use SFC3;

create table TableNames
(
	ID bigint not null,
	Locked DateTime,
	LockID int,

	Name varchar( 255 ) not null,
	primary key (ID)
);

create table TurnDescription
(
	ID bigint not null,
	Locked DateTime,
	LockID int,

	Turn bigint not null,

	primary key (ID)
);

create table DatabaseDescription
(
	ID bigint not null,
	Locked DateTime,
	LockID int,

	NextID bigint not null,
	NextLockID int not null,

	primary key (ID)
);


create table MapDescription 
(
	ID bigint not null,
	Locked DateTime,
	LockID int,
	
	Width int not null,
	Height int not null,

	primary key (ID)
);
	 
create table MapHex 
(
	ID bigint not null,
	Locked DateTime,
	LockID int,

	X int not null,
	Y int not null,
	Race int not null,
	PlanetRace int not null,
	TerrainType int not null,
	PlanetType int not null,
	StarbaseType int not null,
	BaseEconomicPoints int not null,
	CurrentEconomicPoints int not null,
	BaseVictoryPoints int not null,
	CurrentVictoryPoints int not null,
	BaseSpeedPoints double not null,
	CurrentSpeedPoints double not null,

	primary key (ID),

	unique index XYIndex (X, Y)
);
	
create table PoliticalTensionMatrix
(
	ID bigint not null,
	Locked DateTime,
	LockID int,

	MatrixSize int not null,
	Matrix blob not null,
	AllyRatio double not null,
	NeutralRatio double not null,

	primary key (ID)
);

create table ServCharacter
(
	ID bigint not null,
	Locked DateTime,
	LockID int,

	WONLogon varchar(255) not null,
	LastLoggedOn bigint not null,
	MissionsPlayedVector text not null,
	IPAddress varchar(15) not null,
	NextMissionTitle varchar(255) not null,
	NextMissionScore bigint not null,
	HomeWorldLocationX int not null,
	HomeWorldLocationY int not null,
	LastMustPlayLocationX int not null,
	LastMustPlayLocationY int not null,
	PreparedMissionsID bigint not null,
	OpenShipBids varchar(255) not null,
	CharacterName varchar(255) not null,
	ShipCacheVectorSize bigint not null,
	ShipCacheVector blob not null,
	StarbaseID bigint not null,
	StarbaseClass bigint not null,
	CharacterRace bigint not null,
	CharacterRank bigint not null,
	Flags int not null,
	CharacterLastBattleResult float not null,
	CharacterLocationX int not null,
	CharacterLocationY int not null,
	CharacterRating bigint not null,
	Medals int not null,
	CharacterCurrentPrestige bigint not null,
	CharacterLifetimePrestige bigint not null,
	CharacterCurrentDisrepute bigint not null,
	CharacterLifetimeDisrepute bigint not null,
	CharacterBattlesPlayed bigint not null,
	MissionSlotIdx bigint not null,
	MoveCompletes int not null,
	MoveDestinationX int not null,
	MoveDestinationY int not null,
	HailSize bigint not null,
	Hail blob not null,
	Personality int not null,
	GoalState int not null,
	GoalIDs varchar(255) not null,
	FleetLeaderID bigint not null,
	FleetIDs varchar(255) not null,
	DismissedIDs varchar(255) not null,
	FleetName varchar(255) not null,
	ServLanguage bigint not null,

	primary key (ID),
	index (CharacterName),
	index (WONLogon)
);
	
create table BidItem
(
	ID bigint not null,
	Locked DateTime,
	LockID int,

	BiddingHasBegun tinyint not null,
	ItemDescription varchar(255) not null,
	ItemID bigint not null,
	ItemInfo int not null,
	AuctionValue int not null,
	AuctionRate double not null,
	TurnOpened bigint not null,
	TurnToClose bigint not null,
	Closing int not null,
	CurrentBid bigint not null,
	BidOwnerID bigint not null,
	TurnBidMade bigint not null,
	BidMaximum bigint not null,
	Escrow int not null,
	ItemDetailsSize bigint not null,
	ItemDetails blob not null,

	primary key (ID),
	
	index (BidOwnerID),
	index (ItemID)
);	
	
create table Ship
(
	ID bigint not null,
	Locked DateTime,
	LockID int,

	Owner bigint not null,
	IsInAuction tinyint not null,
	Race bigint not null,
	ClassType bigint not null,
	EPV int not null,
	ShipClassName varchar(255) not null,
	TurnCreated int not null,
	Name varchar(255) not null,

	TNGShipSize bigint not null,
	TNGShip blob not null,

	DamageSize bigint not null,
	Damage blob not null,

	StoresSize bigint not null,
	Stores blob not null,

	Flags int not null,
	RawHullCost int not null,

	primary key (ID)
);		
	
create table CampaignInfo
(
	ID bigint not null,
	Locked DateTime,
	LockID int,

	TemplateName varchar(255) not null,
	Description varchar(255) not null,
	EarlyMapName varchar(255) not null,
	MidMapName varchar(255) not null,
	LateMapName varchar(255) not null,
	MissionList text not null,
	RaceList varchar(255) not null,
	CampaignDifficulty bigint not null,
	TriggerPrestige bigint not null,
	TriggerMission varchar(255) not null,
	CampaignName varchar(255) not null,
	CharacterName varchar(255) not null,
	CharacterRace bigint not null,
	ServerPassword varchar(255) not null,
	CurrentTurn int not null,
	CurrentYear int not null,
	CurrentTurnsPerYear int not null,
	CurrentMilliSecondsPerTurn int not null,
	CurrentBaseYear int not null,
	PlayersCurrent int not null,
	PlayersMax int not null,
	PlayersLoggedOnCurrent int not null,
	PlayersLoggedOnMax int not null,
	ServerVersion varchar(255) not null,
	ValidClientVersion varchar(255) not null,
	GameOver int not null,

	primary key (ID)
);		

create table Notify
(
	ID bigint not null,
	Locked DateTime,
	LockID int,

	Category bigint not null,
	NotifyEvent bigint not null,
	ExtraID bigint not null,
	NameToNotifySize bigint not null,
	NameToNotify blob not null,
	DataID bigint not null,

	primary key (ID)
);

create table NewsStory
(
	ID bigint not null,
	Locked DateTime,
	LockID int,

	PersistenceLevel bigint not null,
	UrgencyLevel bigint not null,
	Category bigint not null,
	MessageEnglish text not null,
	MessageGerman text not null,
	NewsTime bigint not null,
	TimeDetail bigint not null,
	Color bigint not null,

	primary key (ID)
);		

create table PreparedMissions
(
	ID bigint not null,
	Locked DateTime,
	LockID int,

	CharacterID bigint not null,
	MissionProfilesSize bigint not null,
	MissionProfiles blob not null,
	HaveTriggeredMission int not null,
	NearbyCharactersSize bigint not null,
	NearbyCharacters blob not null,
	X int not null,
	Y int not null,

	primary key (ID),
	index (CharacterID)
);		

create table Goal
(
	ID bigint not null,
	Locked DateTime,
	LockID int,

	ActorTypeRawName varchar(255) not null,
	ActorSize bigint not null,
	Actor blob not null,
	Action bigint not null,
	CharacterID bigint not null,

	primary key (ID),
	index (CharacterID)
);

create table Officer
(
	ID bigint not null,
	Locked DateTime,
	LockID int,

	OfficerItemSize bigint not null,
	OfficerItem blob not null,
	AtBaseID bigint not null,
	InReviewID bigint not null,
	AtBaseClass bigint not null,
	AtBaseRace bigint not null,
	Race bigint not null,

	primary key (ID)
);

create table Banned
(
	ID bigint not null,
	Locked DateTime,
	LockID int,

	IPAddress varchar(255),
	GameSpyName varchar(255),

	primary key (ID),
	index (IPAddress),
	index (GameSpyName)
);



# NOTE:  The following rules apply:
# 1) These table names much match the names used internal to Server (AsyncDBMulti.cpp)
# 2) The ID/order is not important, but must NOT change for the life of the database (until restarted)
# 3) During the life of the database, you can add to this table, but not modify or delete
# 4) This table will be REMOVED once I add the "show tables" logic to the server
insert into TableNames ( ID, Name )
	Values
	(  2, "TableNames"						),
	(  3, "TurnDescription"					),
	(  4, "DatabaseDescription"				),
	(  5, "MapDescription"					),
	(  6, "MapHex"							),
	(  7, "PoliticalTensionMatrix"			),
	(  8, "ServCharacter"					),
	(  9, "BidItem"							),
	( 10, "Ship"							),
	( 11, "CampaignInfo"					),
	( 12, "Notify"							),
	( 13, "NewsStory"						),
	( 14, "PreparedMissions"				),
	( 15, "Goal"							),
	( 16, "Officer"							),
	( 17, "Banned"							);

insert into DatabaseDescription ( ID, Locked, LockID, NextID, NextLockID ) Values( 1, '1969-12-31 16:00:00', 0, 18, 1 );

show tables;
select * from DatabaseDescription;
select * from TableNames;
